#!/usr/bin/env python3
# -*- coding: utf8 -*-
# test encoding: à-é-è-ô-ï-€

# Copyright 2021 University of Liège
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import numpy as np
from flutter.fluid import Fluid

class UnmatchedFluid(Fluid):
    """Base class to evaluate the fluid freestream density and velocity
    """
    def __init__(self, rho, u, lr, om, mu):
        super().__init__()
        self.rho = rho # constant freestream density
        self.u = u # speed index
        self.lref = lr # reference length
        self.omega = om # natural angular frequency of first torsional mode
        self.mu = mu # mass ratio
        self.n = len(u) # number of test points
    def __str__(self):
        return ('Unmatched fluid with\n'
                + 'density: {:5.2f}\n'.format(self.rho)
                + 'speed index: {}\n'.format(self.u)
                + 'reference length: {:5.2f}\n'.format(self.lref)
                + 'reference frequency: {:5.2f}\n'.format(self.omega)
                + 'mass ratio: {:5.2f}'.format(self.mu)
                )

    def evalRhoU(self, m):
        """Get freestream velocities and constant density
            m: Mach number
        """
        rho = self.rho * np.ones(len(self.u)) # constant freestream density
        u = self.u * (self.lref * self.omega * np.sqrt(self.mu)) # freestream velocity
        return rho, u
