#!/usr/bin/env python3
# -*- coding: utf8 -*-
# test encoding: à-é-è-ô-ï-€

# Copyright 2021 University of Liège
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import numpy as np
from iops.reader import Reader

class AsciiReader(Reader):
    """Class for reading ASCII data from disk
        caller: directory containing the files to be read
    """
    def __init__(self, caller):
        super().__init__(caller)
    def __str__(self):
        return 'ASCII Reader with reference directory: "{:s}"'.format(self._dir)

    def readMatrix(self, fname, dlm=',', skpr=1):
        """Read ascii formated data and return them in matrix form
            fname: name of file contained in self._dir
            dlm: delimiters (assuming CSV by default)
            skpr: number of lines to skip, typically for headers (1 by default)
        """
        fpth = super()._getFile(fname+'.dat') # return path to file
        print('Reading data from:', fpth, end='... ', flush=True)
        data = np.loadtxt(fpth, delimiter=dlm, skiprows=skpr) # return data in matrix format
        print('done!')
        return data
