#!/usr/bin/env python3
# -*- coding: utf8 -*-
# test encoding: à-é-è-ô-ï-€

# Copyright 2021 University of Liège
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import numpy as np
from iops.writer import Writer

class AsciiWriter(Writer):
    """Class for writing ASCII data to disk
    """
    def __init__(self):
        super().__init__()
    def __str__(self):
        return 'ASCII Writer'

    def write(self, fname, data, hdr=''):
        """Write data array to file
            fname: name of the file to be written
            data: matrix formatted data to be written
            hdr: header of the file (empty by default)
        """
        print('Writing data to:', fname+'.dat', end='... ', flush=True)
        np.savetxt(fname+'.dat', data, header=hdr, fmt='%15.6e', delimiter=',')
        print('done!')
