#!/usr/bin/env python3
# -*- coding: utf8 -*-
# test encoding: à-é-è-ô-ï-€

# Copyright 2021 University of Liège
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os.path
import warnings

class Reader:
    """Base class for reading data from disk
        caller: directory containing the files to be read
    """
    def __init__(self, caller):
        if os.path.isfile(caller):
            self._dir = os.path.realpath(os.path.dirname(caller)) # absolute canonical path of directory containing caller file
        elif os.path.isdir(caller):
            self._dir = os.path.realpath(caller) # absolute canonical path of caller directory
        else:
            raise RuntimeError('Reader: directory "' + caller + '" is neither a directory, nor a file!')
    def __str__(self):
        return 'Abstract Reader with reference directory: "{:s}"'.format(self.dir)

    def _getFile(self, fname):
        """Check if file exists and returns complete path
            fname: name of file contained in self._dir
        """
        if os.path.isabs(fname):
            fl = os.path.realpath(fname)
            warnings.warn('Reader._getFile: given file path is absolute but should be relative, is that really the file that you are looking for?\n', RuntimeWarning)
        else:
            fl = os.path.join(self._dir, fname) # should also work if fname is absolute
        if os.path.isfile(fl):
            return fl
        else:
            raise RuntimeError('Reader: file "' + fl + '" not found!')

    def readMatrix(self, fname, dlm, skpr):
        raise NotImplementedError()

    def readGrid(self, fname):
        raise NotImplementedError()

    def readValues(self, fname):
        raise NotImplementedError()
