#!/usr/bin/env python3
# -*- coding: utf8 -*-
# test encoding: à-é-è-ô-ï-€

# Copyright 2021 University of Liège
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import numpy as np
from msh.cell import Cell

class Tri(Cell):
    """Triangle cell, made of 3 nodes
    """
    def __init__(self, idx, nodes):
        super().__init__(idx, nodes)

    def type(self):
        return 'TRI'

    def evalNormalArea(self):
        """Compute unit normal vector to triangle and triangle area using cross product fromula
        """
        x0 = self.nodes[0].x
        x1 = self.nodes[1].x
        x2 = self.nodes[2].x
        n = np.cross(x1 - x0, x2 - x0)
        nrm = np.linalg.norm(n)
        return n / nrm, 0.5 * nrm
